@import url("about:nscolours.css");

html, body {
	margin: 0;
	padding: 0; }

html {
	padding: 2em;
}

body {
	font-family: sans-serif;
	font-size: 94%;
	margin: 0 auto;
	position: relative;
	border-width: 2px;
	border-style: solid; }

h1, h2, h3, h4, h5, h6, h7, p, ul, dl, ol, table {
	margin-left: 5mm;
	margin-right: 5mm; }

h1 {
	font-size: 200%;
	font-weight: bold;
	padding: 5mm;
	margin: 0;
	border-bottom-width: 2px;
	border-bottom-style: solid; }

h2 {
	font-size: 160%;
	padding-top: 5mm;
	border-top-width: 1px;
	border-top-style: solid; }

h1+h2 {
	border-top: none;
}

h3 {
	font-size: 140%;
	font-weight: bold; }

h4 {
	font-size: 120%;
	font-weight: bold; }

h5 {
	font-size: 120%;
	font-style: italic; }

h1, h2, h3 {
	clear: both; }

dl {
	padding: 0; }

dt {
	padding: 0;
	font-weight: bold;
	margin-bottom: 0.3em; }

dd {
	padding: 0;
	margin-left: 5mm;
	margin-bottom: 1em; }

dd > ul {
	margin-top: 0;
	margin-left: 0.5em;
	padding-left: 0;
	margin-bottom: 1em; }

.footer {
	clear: both;
	font-style: italic;
	text-align: right; }

.footer p {
	margin-top: 1.5em;
	padding-top: 0.4em;
	border-top-width: 2px;
	border-top-style: solid; }

input.default-action {
	color: white;
	background: rgb(0, 96, 223);
	border-color: rgb(0, 96, 223);
}

/*
 * Directory Listing Style
 */

body#dirlist {
	padding-bottom: 2em; }

body#dirlist p {
	padding: 2px 5mm;
	margin: 0; }

body#dirlist div {
	display: table;
	width: 94%;
	margin: 5mm auto 2em auto;
	padding: 0; }

body#dirlist strong {
	display: table-row;
	margin: 0;
	padding: 0;
	font-size: 120%;
}

body#dirlist a {
	display: table-row;
	margin: 0;
	padding: 0; }

body#dirlist span {
	display: table-cell;
	vertical-align: middle; }

body#dirlist a > span {
	padding-top: 0.1em; }

body#dirlist em > span {
	padding-bottom: 1px; }

body#dirlist a + a>span {
	border-top-width: 1px;
	border-top-style: solid; }

body#dirlist a {
	background-position: 4px 50%;
	background-repeat: no-repeat;
}

body#dirlist a.dir {
	background-image: url("resource:icons/directory.png"); }

body#dirlist a.file {
	background-image: url("resource:icons/content.png"); }

body#dirlist span.name {
	padding-left: 27px;
	min-height: 20px;}

body#dirlist a.dir > span.name {
	font-weight: bold; }

body#dirlist a.dir > span.type {
	font-weight: bold; }

body#dirlist span.size {
	text-align: right;
	padding-right: 0.3em; }

body#dirlist span.size + span.size {
	text-align: left;
	padding-right: 0; }


/*
 * certificate display style
 */
body#certificate table.info {
	width: 90%;
	margin: 1.2em auto 0;
}

body#certificate table.info th {
	width: 14em;
	vertical-align: top;
	text-align: right;
	font-weight: bold;
	font-family: sans-serif;
	padding-right: 1em;
}

body#certificate table.info td.data {
	font-family: monospace;
	font-size: 90%;
}


/* 
 * configuration listing style 
 */

body#configlist table.config {
	border-spacing: 0;
	font-size: 85%;
	margin: 1.3em 0;
	width: 100%;
	box-sizing: border-box }

body#configlist table.config tr:first-child th {
	text-align: left;
	font-weight: bold;
	font-family: sans-serif; }

body#configlist table.config tr th {
	text-align: left;
	font-weight: normal;
	font-family: monospace; }

body#configlist table.config tr+tr th,
body#configlist table.config tr+tr td {
	border-top-width: 1px;
	border-top-style: solid;
}

body#configlist table.config td, body#configlist table.config th {
	padding-left: 1em; }

body#configlist table.config tr *:nth-child(3) {
	padding-left: 3em; }

body#configlist table.config tr *:nth-child(4) {
	padding-left: 3em;
	font-family: monospace;
	padding-right: 1em; }

body#configlist .null-content {
	font-style: italic; }


/*
 * about:imagecache
 */

p.imagecachelist {
	border-spacing: 0px;
	margin-top: 1.2em;
	margin-bottom: 1.2em;
	display: table;
}

p.imagecachelist strong, p.imagecachelist a {
	display: table-row;
}

p.imagecachelist span {
	padding: 2px 0.5em;
	display: table-cell;
}

p.imagecachelist a+a span {
	border-top-width: 1px;
	border-top-style: solid;
}

/*
 * authentication query styling
 */

body#authentication {
    max-width: 45em;
}

body#authentication form {
  /* Just to center the form on the page */
  margin: 0 auto;
  /* To see the outline of the form */
  padding: 1em;
}

body#authentication table {
  box-sizing: border-box;
  width: 100%;
  margin: 1.5em auto;
}

body#authentication label {
  /* To make sure that all labels have the same size and are properly aligned */
  display: inline-block;
  text-align: right;
}

body#authentication table th {
  text-align: right;
}

body#authentication table td {
  text-align: left;
}

body#authentication table input {
  /* To give the same size to all text fields */
  width: 20em;
  box-sizing: border-box;
  margin-right: 10%;

  /* To harmonize the look & feel of text field border */
  border: 1px solid #999;
}

body#authentication div#buttons {
  text-align: right;
  margin-right: 1em;
}

body#authentication div#buttons input#login {
  margin-right: 1em;
}

/*
 * privacy query styling
 */

body#privacy {
  max-width: 45em;
}

body#privacy form {
  /* Just to center the form on the page */
  margin: 0 auto;
  /* To see the outline of the form */
  padding: 1em;
}

body#privacy form div + div {
  margin-top: 1em;
}

body#privacy div#buttons {
    text-align: right;
    margin-right: 1em;
}

body#privacy div#buttons input#back {
  margin-right: 1em;
}

/*
 * timeout query styling
 */

body#timeout {
  max-width: 45em;
}

body#timeout form {
  /* Just to center the form on the page */
  margin: 0 auto;
  /* To see the outline of the form */
  padding: 1em;
}

body#timeout form div + div {
  margin-top: 1em;
}

body#timeout div#buttons {
    text-align: right;
    margin-right: 1em;
}

body#timeout div#buttons input#back {
  margin-right: 1em;
}

/*
 * fetch error query styling
 */

body#fetcherror {
  max-width: 45em;
}

body#fetcherror form {
  /* Just to center the form on the page */
  margin: 0 auto;
  /* To see the outline of the form */
  padding: 1em;
}

body#fetcherror form div + div {
  margin-top: 1em;
}

body#fetcherror div#buttons {
    text-align: right;
    margin-right: 1em;
}

body#fetcherror div#buttons input#back {
  margin-right: 1em;
}
